#!/usr/bin/env python3
# -*- coding:utf-8 -*-

from ArticutAPI import Articut

username = ""
apikey = ""
articut = Articut(username, apikey)

def verbExtractor():
    verbLIST = []
    with open("詞目.csv", encoding="utf-8") as f:
        entryLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    with open("義項.csv", encoding="utf-8") as f:
        meaningLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    idLIST = []
    for i in meaningLIST:
        if len(i) == 1:
            pass
        elif i[2] in ("動詞",):
            idLIST.append(i[0])
    for e in entryLIST:
        if e[0] in idLIST and e[2] not in verbLIST:
            resultDICT = articut.parse(e[2])
            if resultDICT["result_pos"][0] == "<ACTION_verb>{}</ACTION_verb>".format(e[2]):
                pass
            else:
                verbLIST.append(e[2])
    with open("ACTION_verb.py", mode="w", encoding="utf-8") as f:
        f.write('{}["{}"]'.format("moe_ActionVerb = ", '","'.join(verbLIST)))

def modifierExtractor():
    modifierLIST = []
    with open("詞目.csv", encoding="utf-8") as f:
        entryLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    with open("義項.csv", encoding="utf-8") as f:
        meaningLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    idLIST = []
    for i in meaningLIST:
        if len(i) == 1:
            pass
        elif i[2] in ("副詞", "形容詞"):
            idLIST.append(i[0])

    for e in entryLIST:
        if e[0] in idLIST and e[2] not in modifierLIST and e[2] not in "一二三四五六七八九十兩":
            resultDICT = articut.parse(e[2])
            if resultDICT["result_pos"][0] == "<MODIFIER>{}</MODIFIER>".format(e[2]):
                pass
            else:
                modifierLIST.append(e[2])
    with open("MODIFIER.py", mode="w", encoding="utf-8") as f:
        f.write('{}["{}"]'.format("moe_Modifier = ", '","'.join(modifierLIST)))

def idiomExtractor():
    idiomLIST = []
    with open("詞目.csv", encoding="utf-8") as f:
        entryLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    with open("義項.csv", encoding="utf-8") as f:
        meaningLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    idLIST = []
    for i in meaningLIST:
        if len(i) == 1:
            pass
        elif i[2] in ("熟語",):
            idLIST.append(i[0])

    for e in entryLIST:
        if e[0] in idLIST and e[2] not in idiomLIST:
            resultDICT = articut.parse(e[2])
            if resultDICT["result_pos"][0] == "<IDIOM>{}</IDIOM>".format(e[2]):
                pass
            else:
                idiomLIST.append(e[2])
    with open("IDIOM.py", mode="w", encoding="utf-8") as f:
        f.write('{}["{}"]'.format("moe_Idiom = ", '","'.join(idiomLIST)))

def particleExtractor():
    particleLIST = []
    with open("詞目.csv", encoding="utf-8") as f:
        entryLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    with open("義項.csv", encoding="utf-8") as f:
        meaningLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    idLIST = []
    for i in meaningLIST:
        if len(i) == 1:
            pass
        elif i[2] in ("擬聲詞",):
            idLIST.append(i[0])

    for e in entryLIST:
        if e[0] in idLIST and e[2] not in particleLIST:
            resultDICT = articut.parse(e[2])
            if resultDICT["result_pos"][0] == "<CLAUSE_particle>{}</CLAUSE_particle>".format(e[2]):
                pass
            else:
                particleLIST.append(e[2])
    with open("CLAUSE_particle.py", mode="w", encoding="utf-8") as f:
        f.write('{}["{}"]'.format("moe_ClauseParticle = ", '","'.join(particleLIST)))

def pronounExtractor():
    pronounLIST = []
    with open("詞目.csv", encoding="utf-8") as f:
        entryLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    with open("義項.csv", encoding="utf-8") as f:
        meaningLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    idLIST = []
    for i in meaningLIST:
        if len(i) == 1:
            pass
        elif i[2] in ("代詞",):
            idLIST.append(i[0])

    for e in entryLIST:
        if e[0] in idLIST and e[2] not in pronounLIST:
            resultDICT = articut.parse(e[2])
            if resultDICT["result_pos"][0] == "<ENTITY_pronoun>{}</ENTITY_pronoun>".format(e[2]):
                pass
            else:
                pronounLIST.append(e[2])
    with open("ENTITY_pronoun.py", mode="w", encoding="utf-8") as f:
        f.write('{}["{}"]'.format("moe_EntityPronoun = ", '","'.join(pronounLIST)))

def locativeExtractor():
    pronounLIST = []
    with open("詞目.csv", encoding="utf-8") as f:
        entryLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    with open("義項.csv", encoding="utf-8") as f:
        meaningLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    idLIST = []
    for i in meaningLIST:
        if len(i) == 1:
            pass
        elif i[2] in ("方位詞",):
            idLIST.append(i[0])

    for e in entryLIST:
        if e[0] in idLIST and e[2] not in pronounLIST:
            resultDICT = articut.parse(e[2])
            if resultDICT["result_pos"][0] == "<RANGE_locality>{}</RANGE_locality>".format(e[2]):
                pass
            else:
                pronounLIST.append(e[2])
    with open("RANGE_locality.py", mode="w", encoding="utf-8") as f:
        f.write('{}["{}"]'.format("moe_RangeLocality = ", '","'.join(pronounLIST)))

def conjunctionExtractor():
    conjunctionLIST = []
    with open("詞目.csv", encoding="utf-8") as f:
        entryLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    with open("義項.csv", encoding="utf-8") as f:
        meaningLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    idLIST = []
    for i in meaningLIST:
        if len(i) == 1:
            pass
        elif i[2] in ("連詞",):
            idLIST.append(i[0])

    for e in entryLIST:
        if e[0] in idLIST and e[2] not in conjunctionLIST:
            resultDICT = articut.parse(e[2])
            if resultDICT["result_pos"][0] == "<FUNC_conjunction>{}</FUNC_conjunction>".format(e[2]):
                pass
            else:
                conjunctionLIST.append(e[2])
    with open("FUNC_conjunction.py", mode="w", encoding="utf-8") as f:
        f.write('{}["{}"]'.format("moe_FuncConjunction = ", '","'.join(conjunctionLIST)))

def classifierExtractor():
    classifierLIST = []
    with open("詞目.csv", encoding="utf-8") as f:
        entryLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    with open("義項.csv", encoding="utf-8") as f:
        meaningLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    idLIST = []
    for i in meaningLIST:
        if len(i) == 1:
            pass
        elif i[2] in ("量詞",):
            idLIST.append(i[0])

    for e in entryLIST:
        if e[0] in idLIST and e[2] not in classifierLIST and e[2] not in "一二三四五六七八九十兩"::
            resultDICT = articut.parse(e[2])
            if resultDICT["result_pos"][0] == "<ENTITY_classifier>{}</ENTITY_classifier>".format(e[2]):
                pass
            else:
                classifierLIST.append(e[2])
    with open("ENTITY_classifier.py", mode="w", encoding="utf-8") as f:
        f.write('{}["{}"]'.format("moe_EntityClassifier = ", '","'.join(classifierLIST)))

def justtimeExtractor():
    justtimeLIST = []
    with open("詞目.csv", encoding="utf-8") as f:
        entryLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    with open("義項.csv", encoding="utf-8") as f:
        meaningLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    idLIST = []
    for i in meaningLIST:
        if len(i) == 1:
            pass
        elif i[2] in ("時間詞",):
            idLIST.append(i[0])

    for e in entryLIST:
        if e[0] in idLIST and e[2] not in justtimeLIST:
            resultDICT = articut.parse(e[2])
            if resultDICT["result_pos"][0].startswith("<TIME_"):
                pass
            else:
                justtimeLIST.append(e[2])
    with open("TIME_justtime.py", mode="w", encoding="utf-8") as f:
        f.write('{}["{}"]'.format("moe_TimeJusttime = ", '","'.join(justtimeLIST)))

def funcinnerExtractor():
    funcinnerLIST = []
    with open("詞目.csv", encoding="utf-8") as f:
        entryLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    with open("義項.csv", encoding="utf-8") as f:
        meaningLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    idLIST = []
    for i in meaningLIST:
        if len(i) == 1:
            pass
        elif i[2] in ("介詞",):
            idLIST.append(i[0])

    for e in entryLIST:
        if e[0] in idLIST and e[2] not in funcinnerLIST:
            resultDICT = articut.parse(e[2])
            if resultDICT["result_pos"][0] == "<FUNC_inner>{}</FUNC_inner>".format(e[2]):
                pass
            else:
                funcinnerLIST.append(e[2])
    with open("FUNC_inner.py", mode="w", encoding="utf-8") as f:
        f.write('{}["{}"]'.format("moe_FuncInner = ", '","'.join(funcinnerLIST)))

def locationExtractor():
    locationLIST = []
    with open("詞目.csv", encoding="utf-8") as f:
        entryLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    with open("義項.csv", encoding="utf-8") as f:
        meaningLIST = [i.replace("\n", "").split(",") for i in f.read().split("\n")]
    idLIST = []
    for i in meaningLIST:
        try:
            if len(i) == 1:
                pass
            elif "－地名－" in i[3]:
                idLIST.append(i[0])
            elif "—山線" in i[4]:
                idLIST.append(i[0])
            elif "支線—" in i[4]:
                idLIST.append        (i[0])
            elif i[-1].replace("\n", "").endswith("站名"):
                idLIST.append(i[0])
            elif i[-1].replace("\n", "").endswith("捷運"):
                idLIST.append(i[0])
            elif i[-1].replace("\n", "").endswith("鐵路"):
                idLIST.append(i[0])
            elif i[-1].replace("\n", "").endswith("線"):
                idLIST.append(i[0])
            elif i[-1].replace("\n", "").endswith("輕軌"):
                idLIST.append(i[0])
        except IndexError:
            pass

    for e in entryLIST:
        if e[0] in idLIST and e[2] not in locationLIST:
            locationLIST.append(e[2])
    with open("LOCATION.py", mode="w", encoding="utf-8") as f:
        f.write('{}["{}"]'.format("moe_Location = ", '","'.join(locationLIST)))

if __name__ == "__main__":
    #verbExtractor()
    #modifierExtractor()
    #idiomExtractor()
    #particleExtractor()
    #pronounExtractor()
    #locationExtractor()
    locativeExtractor()
    #conjunctionExtractor()
    #classifierExtractor()
    #justtimeExtractor()
    #funcinnerExtractor()
    #locationExtractor()


#!/usr/bin/env python3
# -*- coding:utf-8 -*-

import tempfile
import platform

try:
    from moe_dict.ACTION_verb import moe_ActionVerb
    from moe_dict.CLAUSE_particle import moe_ClauseParticle
    from moe_dict.CLAUSE_Q import moe_ClauseQ
    from moe_dict.ENTITY_classifier import moe_EntityClassifier
    from moe_dict.ENTITY_noun import moe_EntityNoun
    from moe_dict.ENTITY_pronoun import moe_EntityPronoun
    from moe_dict.FUNC_conjunction import moe_FuncConjunction
    from moe_dict.FUNC_inner import moe_FuncInner
    from moe_dict.FUNC_inter import moe_FuncInter
    from moe_dict.IDIOM import moe_Idiom
    from moe_dict.LOCATION import moe_Location
    from moe_dict.MODIFIER import moe_Modifier
    from moe_dict.RANGE_locality import moe_RangeLocality
    from moe_dict.TIME_justtime import moe_TimeJusttime
    from moe_dict.TIME_season import moe_TimeSeason

    from DroidtownTG_dict.ACTION_eventQuantifier import DT_ActionEventQuantifier
    from DroidtownTG_dict.ACTION_lightVerb import DT_ActionLightVerb
    from DroidtownTG_dict.ACTION_quantifiedVerb import DT_ActionQuantifiedVerb
    from DroidtownTG_dict.ACTION_verb import DT_ActionVerb
    from DroidtownTG_dict.ASPECT import DT_Aspect
    from DroidtownTG_dict.AUX import DT_Aux
    from DroidtownTG_dict.CLAUSE_particle import DT_ClauseParticle
    from DroidtownTG_dict.CLAUSE_Q import DT_ClauseQ
    from DroidtownTG_dict.ENTITY_classifier import DT_EntityClassifier
    from DroidtownTG_dict.ENTITY_DetPhrase import DT_EntityDetPhrase
    from DroidtownTG_dict.ENTITY_measurement import DT_EntityMeasurement
    from DroidtownTG_dict.ENTITY_noun import DT_EntityNoun
    from DroidtownTG_dict.ENTITY_num import DT_EntityNum
    from DroidtownTG_dict.ENTITY_person import DT_EntityPerson
    from DroidtownTG_dict.ENTITY_possessive import DT_EntityPossessive
    from DroidtownTG_dict.ENTITY_pronoun import DT_EntityPronoun
    from DroidtownTG_dict.FUNC_degreeHead import DT_FuncDegreeHead
    from DroidtownTG_dict.FUNC_inner import DT_FuncInner
    from DroidtownTG_dict.FUNC_inter import DT_FuncInter
    from DroidtownTG_dict.FUNC_negation import DT_FuncNegation
    from DroidtownTG_dict.FUNC_conjunction import DT_FuncConjunction
    from DroidtownTG_dict.IDIOM import DT_Idiom
    from DroidtownTG_dict.LOCATION import DT_Location
    from DroidtownTG_dict.TIME_justtime import DT_TimeJusttime
    from DroidtownTG_dict.MODAL import DT_Modal
    from DroidtownTG_dict.MODIFIER import DT_Modifier
    from DroidtownTG_dict.MODIFIER_color import DT_ModifierColor
    from DroidtownTG_dict.QUANTIFIER import DT_Quantifier
    from DroidtownTG_dict.RANGE_period import DT_RangePeriod
    from DroidtownTG_dict.RANGE_locality import DT_RangeLocality

    from DroidtownTG_dict.toTL import DT_TL
except:
    from .moe_dict.ACTION_verb import moe_ActionVerb
    from .moe_dict.CLAUSE_particle import moe_ClauseParticle
    from .moe_dict.CLAUSE_Q import moe_ClauseQ
    from .moe_dict.ENTITY_classifier import moe_EntityClassifier
    from .moe_dict.ENTITY_noun import moe_EntityNoun
    from .moe_dict.ENTITY_pronoun import moe_EntityPronoun
    from .moe_dict.FUNC_conjunction import moe_FuncConjunction
    from .moe_dict.FUNC_inner import moe_FuncInner
    from .moe_dict.FUNC_inter import moe_FuncInter
    from .moe_dict.IDIOM import moe_Idiom
    from .moe_dict.LOCATION import moe_Location
    from .moe_dict.MODIFIER import moe_Modifier
    from .moe_dict.RANGE_locality import moe_RangeLocality
    from .moe_dict.TIME_justtime import moe_TimeJusttime
    from .moe_dict.TIME_season import moe_TimeSeason

    from .DroidtownTG_dict.ACTION_eventQuantifier import DT_ActionEventQuantifier
    from .DroidtownTG_dict.ACTION_lightVerb import DT_ActionLightVerb
    from .DroidtownTG_dict.ACTION_quantifiedVerb import DT_ActionQuantifiedVerb
    from .DroidtownTG_dict.ACTION_verb import DT_ActionVerb
    from .DroidtownTG_dict.ASPECT import DT_Aspect
    from .DroidtownTG_dict.AUX import DT_Aux
    from .DroidtownTG_dict.CLAUSE_particle import DT_ClauseParticle
    from .DroidtownTG_dict.CLAUSE_Q import DT_ClauseQ
    from .DroidtownTG_dict.ENTITY_classifier import DT_EntityClassifier
    from .DroidtownTG_dict.ENTITY_DetPhrase import DT_EntityDetPhrase
    from .DroidtownTG_dict.ENTITY_measurement import DT_EntityMeasurement
    from .DroidtownTG_dict.ENTITY_noun import DT_EntityNoun
    from .DroidtownTG_dict.ENTITY_num import DT_EntityNum
    from .DroidtownTG_dict.ENTITY_person import DT_EntityPerson
    from .DroidtownTG_dict.ENTITY_possessive import DT_EntityPossessive
    from .DroidtownTG_dict.ENTITY_pronoun import DT_EntityPronoun
    from .DroidtownTG_dict.FUNC_degreeHead import DT_FuncDegreeHead
    from .DroidtownTG_dict.FUNC_inner import DT_FuncInner
    from .DroidtownTG_dict.FUNC_inter import DT_FuncInter
    from .DroidtownTG_dict.FUNC_negation import DT_FuncNegation
    from .DroidtownTG_dict.FUNC_conjunction import DT_FuncConjunction
    from .DroidtownTG_dict.IDIOM import DT_Idiom
    from .DroidtownTG_dict.LOCATION import DT_Location
    from .DroidtownTG_dict.TIME_justtime import DT_TimeJusttime
    from .DroidtownTG_dict.MODAL import DT_Modal
    from .DroidtownTG_dict.MODIFIER import DT_Modifier
    from .DroidtownTG_dict.MODIFIER_color import DT_ModifierColor
    from .DroidtownTG_dict.QUANTIFIER import DT_Quantifier
    from .DroidtownTG_dict.RANGE_period import DT_RangePeriod
    from .DroidtownTG_dict.RANGE_locality import DT_RangeLocality

    from .DroidtownTG_dict.toTL import DT_TL

def dictCombiner():
    '''
    Combine moe dictionary and DroidtownTG_dict
    '''
    combinedDICT = {"ACTION_verb"           : None,
                    "ACTION_lightVerb"      : None,
                    "ACTION_quantifiedVerb" : None,
                    "ACTION_eventQuantifier": None,
                    "ASPECT"                : None,
                    "AUX"                   : None,
                    "CLAUSE_particle"       : None,
                    "CLAUSE_Q"              : None,
                    "ENTITY_classifier"     : None,
                    "ENTITY_DetPhrase"      : None,
                    "ENTITY_measurement"    : None,
                    "ENTITY_noun"           : None,
                    "ENTITY_num"            : None,
                    "ENTITY_person"         : None,
                    "ENTITY_possessive"     : None,
                    "ENTITY_pronoun"        : None,
                    "FUNC_conjunction"      : None,
                    "FUNC_degreeHead"       : None,
                    "FUNC_inner"            : None,
                    "FUNC_inter"            : None,
                    "FUNC_negation"         : None,
                    "FUNC_conjunction"      : None,
                    "IDIOM"                 : None,
                    "LOCATION"              : None,
                    "MODAL"                 : None,
                    "MODIFIER"              : None,
                    "MODIFIER_color"        : None,
                    "QUANTIFIER"            : None,
                    "RANGE_locality"        : None,
                    "RANGE_period"          : None,
                    "TIME_justtime"         : None,
                    "TIME_season"           : None
                    }

    moeDICT = {"ACTION_verb"      : moe_ActionVerb,
               "CLAUSE_particle"  : moe_ClauseParticle,
               "CLAUSE_Q"         : moe_ClauseQ,
               "ENTITY_classifier": moe_EntityClassifier,
               "ENTITY_noun"      : moe_EntityNoun,
               "ENTITY_pronoun"   : moe_EntityPronoun,
               "FUNC_conjunction" : moe_FuncConjunction,
               "FUNC_inner"       : moe_FuncInner,
               "FUNC_inter"       : moe_FuncInter,
               "IDIOM"            : moe_Idiom,
               "LOCATION"         : moe_Location,
               "MODIFIER"         : moe_Modifier,
               "RANGE_locality"   : moe_RangeLocality,
               "TIME_justtime"    : moe_TimeJusttime,
               "TIME_season"      : moe_TimeSeason
    }

    DTDICT = {"ACTION_verb"           : DT_ActionVerb,
              "ACTION_lightVerb"      : DT_ActionLightVerb,
              "ACTION_quantifiedVerb" : DT_ActionQuantifiedVerb,
              "ACTION_eventQuantifier": DT_ActionEventQuantifier,
              "ASPECT"                : DT_Aspect,
              "AUX"                   : DT_Aux,
              "CLAUSE_particle"       : DT_ClauseParticle,
              "CLAUSE_Q"              : DT_ClauseQ,
              "ENTITY_classifier"     : DT_EntityClassifier,
              "ENTITY_DetPhrase"      : DT_EntityDetPhrase,
              "ENTITY_measurement"    : DT_EntityMeasurement,
              "ENTITY_noun"           : DT_EntityNoun,
              "ENTITY_num"            : DT_EntityNum,
              "ENTITY_person"         : DT_EntityPerson,
              "ENTITY_possessive"     : DT_EntityPossessive,
              "ENTITY_pronoun"        : DT_EntityPronoun,
              "FUNC_degreeHead"       : DT_FuncDegreeHead,
              "FUNC_inner"            : DT_FuncInner,
              "FUNC_inter"            : DT_FuncInter,
              "FUNC_negation"         : DT_FuncNegation,
              "FUNC_conjunction"      : DT_FuncConjunction,
              "IDIOM"                 : DT_Idiom,
              "LOCATION"              : DT_Location,
              "TIME_justtime"         : DT_TimeJusttime,
              "MODAL"                 : DT_Modal,
              "MODIFIER"              : DT_Modifier,
              "MODIFIER_color"        : DT_ModifierColor,
              "QUANTIFIER"            : DT_Quantifier,
              "RANGE_period"          : DT_RangePeriod,
              "RANGE_locality"        : DT_RangeLocality
    }


    for POS in combinedDICT.keys():
        try:
            tmpLIST = moeDICT[POS]
            for k in DTDICT.keys():
                tmpLIST = list(set(tmpLIST)-set(DTDICT[k]))
            if POS in DTDICT.keys():
                tmpLIST.extend(DTDICT[POS])
            tmpLIST = list(set(tmpLIST))
            combinedDICT[POS] = tmpLIST
        except KeyError:
            combinedDICT[POS] = DTDICT[POS]

        #try:
            #tmpLIST = []
            #for p in posLIST:
                #if re.search(self.cjkPAT, p.strip()):
                    #tmpLIST.append(p.strip())
                #else:
                    #for w in (p.strip().lower(), p.strip().upper(), p.strip().title(), p.strip().capitalize(), p.strip()):
                        #tmpLIST.append(" {}".format(w))
                        #tmpLIST.append("{} ".format(w))
                        #tmpLIST.append(" {} ".format(w))
                        #tmpLIST.append("{}".format(w))
            #if tmpLIST != []:
                #combinedDICT[POS].extend(tmpLIST)
            #combinedDICT[POS] = list(set(combinedDICT[POS]))
        #except FileNotFoundError:
            #pass

    #if platform.system() == "Windows":
        #defaultDictFILE = tempfile.NamedTemporaryFile(mode="w+", delete=False)
    #else:
        #defaultDictFILE = tempfile.NamedTemporaryFile(mode="w+")
    #json.dump(combinedDICT, defaultDictFILE)
    #defaultDictFILE.flush()


    return combinedDICT


if __name__ == "__main__":
    combinedDICT = dictCombiner()
    print(combinedDICT["TIME_justtime"])


import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="ArticutAPI_Taigi",
    version="0.95",
    author="Droidtown Linguistic Tech. Co. Ltd.",
    author_email="info@droidtown.co",
    description="Articut NLP system provides not only finest results on Chinese word segmentaion (CWS), Part-of-Speech tagging (POS) and Named Entity Recogintion tagging (NER), but also the fastest online API service in the NLP industry.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Droidtown/ArticutAPI_Taigi",
    project_urls={
        "Documentation": "https://api.droidtown.co/ArticutAPI/document/",
        "Source": "https://github.com/Droidtown/ArticutAPI",
    },
    license="MIT License",
    keywords=[
        "NLP", "NLU", "CWS", "POS", "NER", "AI",
        "artificial intelligence",
        "Chinese word segmentation",
        "computational linguistics",
        "language",
        "linguistics",
        "graphQL",
        "natural language",
        "natural language processing",
        "natural language understanding",
        "parsing",
        "part-of-speech-embdding",
        "part-of-speech-tagger",
        "pos-tagger",
        "pos-tagging",
        "syntax",
        "tagging",
        "text analytics"
    ],
    packages=setuptools.find_packages(),
    include_package_data=True,
    install_requires=["requests >= 2.25.1", "ArticutAPI"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 5 - Production/Stable",
        #"Environment :: Console",
        "Intended Audience :: Developers",
        "Intended Audience :: Customer Service",
        "Intended Audience :: Information Technology",
        "Natural Language :: Chinese (Traditional)",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Text Processing",
        "Topic :: Text Processing :: Linguistic",
        "Topic :: Text Processing :: Markup :: XML",
        "Topic :: Text Processing :: Filters",
        "Topic :: Utilities",
    ],
    python_requires=">=3.6.1",
)



DT_EntityPerson = ["陳三",
                   "五娘",
                   "九郎",
                   "伯卿",
                   "阿明",
                   "阿美",
                   "阿珠",
                   "黃九郎",
                   "黃五娘",
                   "陳伯卿",
                   "蔡英文",
                   "陳國文",
                   "阿發仔"
                   ]


DT_FuncDegreeHead = ["遮爾",
                     "閣較",
                     "如此",
                     "非常",
                     "遐爾仔",
                     "遐爾",
                     "愈",
                     "tng-tih",
                     "khah"
                     ]